@@ -80,8 +80,6 @@ def api_extract_batch(vars, request, retries=5) -> DataFrame:
     # create containers to hold requested data
     data = {}
     tract = []
-    county = []
-    state = []
 
     exception = ""
 
@@ -93,8 +91,9 @@ def api_extract_batch(vars, request, retries=5) -> DataFrame:
                 for k in r.json():
                     # Census Tract GEOID: STATE+COUNTY+TRACT (2+3+6 digits)
                     tract.append(k[len(k) - 3] + k[len(k) - 2] + k[len(k) - 1])
-                    county.append(k[len(k) - 2])
-                    state.append(k[len(k) - 3])
+                    
+                    data['county'].append(k[len(k) - 2])
+                    data['state'].append(k[len(k) - 3])
                     # start with the second piece of json data, first piece is not needed
                     json_data_index = 1
                     for var in vars:
@@ -123,8 +122,6 @@ def api_extract_batch(vars, request, retries=5) -> DataFrame:
 
     result_df = pd.DataFrame(data, index=tract)
     result_df.index.names = ['census_tract_geoid']
-    result_df['county'] = county
-    result_df['state'] = state 
     result_df = result_df[1:]
 
     return result_df
